<?php
/**
 * newie functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package newie
 */

if ( ! function_exists( 'newie_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function newie_setup() 
{
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on newie, use a find and replace
	 * to change 'newie' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'newie');

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );

    add_image_size( 'newie-promo-post', 360, 261, array( 'left', 'bottom' ) ); //(cropped)
	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => esc_html__( 'Primary', 'newie' ),
		'social' => esc_html__( 'Social', 'newie' ),
	) );

	/*
	 * Theme custom logo
	 */
	add_theme_support( 'custom-logo', array(
        /*'height'      => 100,
        'width'       => 350,*/ 
        'flex-width'  => true,
    ) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	/*
	 * Enable support for Post Formats.
	 *
	 * See: https://codex.wordpress.org/Post_Formats
	 */
	add_theme_support( 'post-formats', array(
		'aside',
		'image',
		'video',
		'quote',
		'link',
		'gallery',
		'status',
		'audio',
		'chat',
	) );

	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'newie_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );
}

endif;
add_action( 'after_setup_theme', 'newie_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function newie_content_width() 
{
	$GLOBALS['content_width'] = apply_filters( 'newie_content_width', 640 );
}
add_action( 'after_setup_theme', 'newie_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function newie_widgets_init() 
{
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'newie' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'newie' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title"><span>',
		'after_title'   => '</span></h2>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Footer One', 'newie' ),
		'id'            => 'footer-1',
		'description'   => esc_html__( 'Add widgets here', 'newie' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title"><span>',
		'after_title'   => '</span></h2>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Footer Two', 'newie' ),
		'id'            => 'footer-2',
		'description'   => esc_html__( 'Add widgets here', 'newie' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title"><span>',
		'after_title'   => '</span></h2>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Footer Three', 'newie' ),
		'id'            => 'footer-3',
		'description'   => esc_html__( 'Add widgets here', 'newie' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title"><span>',
		'after_title'   => '</span></h2>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Footer Four', 'newie' ),
		'id'            => 'footer-4',
		'description'   => esc_html__( 'Add widgets here', 'newie' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title"><span>',
		'after_title'   => '</span></h2>',
	) );
}
add_action( 'widgets_init', 'newie_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function newie_scripts()
{
 global $newie_theme_options;
   
    $newie_theme_options    = newie_get_theme_options();

    $sticky_menu            = wp_kses_post( $newie_theme_options['show_sticky_menu'] );

    $body_font_name         = wp_kses_post( $newie_theme_options['newie_paragraph_font_url'] );

    $menu_font_name         = wp_kses_post( $newie_theme_options['newie_menu_font_url'] );
    
    $tagline_font_name      = wp_kses_post( $newie_theme_options['newie_site_desc_font_url'] );
    
    $site_title_font_name   = wp_kses_post( $newie_theme_options['newie_font_url'] );
    
    $headline_font_name     = wp_kses_post( $newie_theme_options['newie_heading_font_url'] );


    if(!empty( $body_font_name ))
    {
      	/*google font  */
        wp_enqueue_style( 'newie-body-font', $body_font_name, array(), null );
    }

   if(!empty( $menu_font_name ))
    {
      	/*google font  */
        wp_enqueue_style( 'newie-menu-font', $menu_font_name, array(), null );
    }
 
  if(!empty( $tagline_font_name ))
    {
      	/*google font  */
        wp_enqueue_style( 'newie-menu-tagline', $tagline_font_name, array(), null );
    }

  if(!empty( $site_title_font_name ))
    {
      	/*google font  */
        wp_enqueue_style( 'newie-menu-title', $site_title_font_name, array(), null );
    } 

  if(!empty( $headline_font_name ))
    {
      	/*google font  */
        wp_enqueue_style( 'newie-menu-headline', $headline_font_name, array(), null );
    }      

 if( empty( $menu_font_name ) || empty( $tagline_font_name ) || empty( $site_title_font_name ) || empty($headline_font_name) )
  
  {
  
     /*google font  */
     wp_enqueue_style( 'newie-googleapis', 'https://fonts.googleapis.com/css?family=Hind:300,400,500|Libre+Franklin:400,500|Merriweather:400,700,700i,900', array(), null );

  }
	
	/*Font-Awesome-master*/
    wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/assets/framework/Font-Awesome/css/font-awesome.min.css', array(), '4.5.0' );
	
	/*Bootstrap CSS*/
    wp_enqueue_style( 'bootstrap', get_template_directory_uri() . '/assets/framework/bootstrap/css/bootstrap.min.css', array(), '4.5.0' );
	
	/*Owl CSS*/
    wp_enqueue_style( 'owl-carousel', get_template_directory_uri() . '/assets/framework/owl-carousel/owl.carousel.css', array(), '4.5.0' );
	
	/*Fancybox CSS*/
    wp_enqueue_style( 'fancybox', get_template_directory_uri() . '/assets/framework/fancybox/css/jquery.fancybox.css', array(), '4.5.0' );

	
	/*Style CSS*/
	wp_enqueue_style( 'newie-style', get_stylesheet_uri() );

       global $newie_theme_options;
       $masonry = $newie_theme_options['newie_columns_option'];
	
     if($masonry =="col-sm-6" || $masonry =="col-sm-4"  )
    {

     wp_enqueue_script( 'masonry' );
     wp_enqueue_script('newie-custom-masonary', get_template_directory_uri() . '/assets/js/custom-masonary.js', array('jquery'), '201765', true);
    }	


    /*Bootstrap JS*/
    wp_enqueue_script( 'bootstrap', get_template_directory_uri() . '/assets/framework/bootstrap/js/bootstrap.min.js', array('jquery'), '4.5.0' );
	
	
	/*navigation JS*/
	wp_enqueue_script( 'newie-navigation', get_template_directory_uri() . '/assets/js/navigation.js', array('jquery'), '20151215', true );

	/*owl*/
    wp_enqueue_script( 'owl-carousel', get_template_directory_uri() . '/assets/framework/owl-carousel/owl.carousel.min.js', array('jquery'), '4.5.0' );
	
  
   if( $sticky_menu == 1)   
  {
       wp_enqueue_script( 'newie-sticky_menu ', get_template_directory_uri() . '/assets/js/sticky-menu.js', array('jquery'), '4.5.0' );


    }


  /*fancybox js*/
    wp_enqueue_script( 'fancybox', get_template_directory_uri() . '/assets/framework/fancybox/js/jquery.fancybox.pack.js', array('jquery'), '4.5.0' );

   /*Sticky Sidebar js*/
    wp_enqueue_script( 'sticky-sidebar', get_template_directory_uri() . '/assets/js/theia-sticky-sidebar.js', array('jquery'), '4.5.0' );

	/*Custom JS*/
	wp_enqueue_script( 'scripts', get_template_directory_uri() . '/assets/js/scripts.js', array('jquery'), '4.5.0' );
	

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) 
	{
		wp_enqueue_script( 'comment-reply' );
	}
}

add_action( 'wp_enqueue_scripts', 'newie_scripts' );



/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Loading related post file
 */

require get_template_directory() . '/inc/hooks/related-post.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Loading breadcrumbs File.
 */

if (!function_exists('breadcrumb_trail')) {
 
   require get_template_directory() . '/inc/library/breadcrumbs/breadcrumbs.php';

}


/**
 * Loading page-breadcrumbs in pages/posts
 */

require get_template_directory() . '/inc/hooks/page-breadcrumbs.php';


/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';


/**
 * Load theme-function  file.
 */
require get_template_directory() . '/inc/theme-function.php';

/**
 * Load Custom widget File.
 */
require get_template_directory() . '/inc/custom-widget/author-widget.php';

/**
 * Load Custom widget File.
 */
require get_template_directory() . '/inc/custom-widget/recent-posts.php';

require get_template_directory() . '/inc/custom-widget/social-widget.php';



/**
 * Exclude category in blog page
 *
 * @since Newie 1.0.0
 *
 * @param null
 * @return int
 */
if (!function_exists('newie_exclude_category_in_blog_page')) :
    function newie_exclude_category_in_blog_page($query)
    {

        if ($query->is_home && $query->is_main_query()) {
        	$newie_theme_options    = newie_get_theme_options();
            $catid = $newie_theme_options['newie_exclude_cat_blog_archive_option'];

            $exclude_categories = $catid;
            if (!empty($exclude_categories)) {
                $cats = explode(',', $exclude_categories);
                $cats = array_filter($cats, 'is_numeric');
                $string_exclude = '';
                $string_exclude;
                if (!empty($cats)) {
                    $string_exclude = '-' . implode(',-', $cats);
                    $query->set('cat', $string_exclude);
                }
            }
        }
        return $query;
    }
endif;
add_filter('pre_get_posts', 'newie_exclude_category_in_blog_page');




/**
 * Exclude category in blog page
 *
 * @since Newie 1.0.0
 *
 * @param null
 * @return int
 */
if (!function_exists('newie_exclude_category_form_slider')) :
    function newie_exclude_category_form_slider($query)
    {

        if ($query->is_home && $query->is_main_query()) {

        	$newie_theme_options    = newie_get_theme_options();

        	$selected_opt           = $newie_theme_options['slider-options'];
          
            if( $selected_opt == 'category' )
             {
                 $exclude_id  = $newie_theme_options['newie-feature-cat'];
             }
             elseif ( $selected_opt == 'tags' )
             {
               $exclude_id  = $newie_theme_options['newie-feature-tag'];
             }
             
            
            if (!empty($exclude_id)) {
                $cats = explode(',', $exclude_id);
                $cats = array_filter($cats, 'is_numeric');
                $string_exclude = '';
                 $string_exclude;
                if (!empty($cats)) {
                    $string_exclude = '-' . implode(',-', $cats);
                    $query->set('cat', $string_exclude);
                }
            }
        }
        return $query;
    }
endif;
add_filter('pre_get_posts', 'newie_exclude_category_form_slider');




/**
 * Admin Enqueue scripts and styles.
 */
if ( ! function_exists( 'newie_admin_scripts' ) ) {
    function newie_admin_scripts($hook) {
        if( 'widgets.php' != $hook )
            return;
        if (function_exists('wp_enqueue_media')){
            wp_enqueue_media();
        }
        wp_enqueue_script('newie-media-uploader', get_template_directory_uri() . '/assets/js/admin.js', array( 'jquery', 'customize-controls' ) );
       
        wp_enqueue_style( 'font-awesome', get_template_directory_uri().'/assets/framework/Font-Awesome/css/font-awesome.min.css' );
        wp_enqueue_style( 'newie-style-admin', get_template_directory_uri() . '/assets/css/admin.css');
    }
}
add_action('admin_enqueue_scripts', 'newie_admin_scripts');


/**
 * Reset css
 */
require get_template_directory() . '/inc/hooks/reset-css.php';

/**
 * Load Dynamic css.
 */
$newie_theme_options    = newie_get_theme_options();

$dynamic_css_options    = $newie_theme_options['newie_color_reset_option'];

if ($dynamic_css_options == "do-not-reset" || $dynamic_css_options == "") {

    include get_template_directory() . '/inc/hooks/dynamic-css.php';

} elseif ($dynamic_css_options == "reset-all") {
      do_action('newie_reset_colors');
   
}



function newie_theme_updater() {
    
    require( get_template_directory() . '/inc/updater/theme-updater.php' );
}
add_action( 'after_setup_theme', 'newie_theme_updater' );