<?php
/**
 * newie Theme Customizer.
 *
 * @package newie
 */


/**
 * Sanitizing the repeater Field
 *
 * @since newie 1.0.0
 * @param $input
 * @param $setting
 * @return sanitized output
 *
 */
function newie_sanitize_repeater($input){
      
    $input_decoded = json_decode( $input, true );
    $allowed_html = array(
        'br' => array(),
        'em' => array(),
        'strong' => array(),
        'a' => array(
            'href' => array(),
            'class' => array(),
            'id' => array(),
            'target' => array()
        ),
        'button' => array(
            'class' => array(),
            'id' => array()
        )
    );
    
    
    if(!empty($input_decoded)) {
        foreach ($input_decoded as $boxes => $box ){
            foreach ($box as $key => $value){
                $input_decoded[$boxes][$key] = sanitize_text_field( $value );
            }
        }

        return json_encode($input_decoded);
    }
    
    return $input;
}





/**
 * Sanitizing the select callback example
 *
 * @since newie 1.0.0
 *
 * @see sanitize_key()https://developer.wordpress.org/reference/functions/sanitize_key/
 * @see $wp_customize->get_control() https://developer.wordpress.org/reference/classes/wp_customize_manager/get_control/
 *
 * @param $input
 * @param $setting
 * @return sanitized output
 *
 */
if ( !function_exists('newie_sanitize_select') ) :
    function newie_sanitize_select( $input, $setting ) 
   {

        // Ensure input is a slug.
        $input = sanitize_key( $input );

        // Get list of choices from the control associated with the setting.
        $choices = $setting->manager->get_control( $setting->id )->choices;

        // If the input is a valid key, return it; otherwise, return the default.
        return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
    }
endif;


/**
 * Sanitize checkbox field
 *
 * @since Newie 1.0.0
 *
 * @param $checked
 * @return Boolean
 */
if ( !function_exists('newie_sanitize_checkbox') ) :
    function newie_sanitize_checkbox( $checked ) {
        // Boolean check.
        return ( ( isset( $checked ) && true == $checked ) ? true : false );
    }
endif;


/**
 * Sidebar layout options
 *
 * @since newie 1.0.0
 *
 * @param null
 * @return array $newie_sidebar_layout
 *
 */
if ( !function_exists('newie_sidebar_layout') ) :
    function newie_sidebar_layout()
    {
        $newie_sidebar_layout =  array(
            'right-sidebar' => __( 'Right Sidebar', 'newie'),
            'left-sidebar'  => __( 'Left Sidebar' , 'newie'),
            'no-sidebar'    => __( 'No Sidebar', 'newie')
        );
        return apply_filters( 'newie_sidebar_layout', $newie_sidebar_layout );
    }
endif;





/**
 * newie select_number of columns option for blog post
 *
 * @since Newie 1.0.0
 *
 * @param null
 * @return array $newie_select_number_of_column
 *
 */
if (!function_exists('newie_select_number_of_column')) :
    function newie_select_number_of_column()
    {
        $newie_select_number_of_column = array(
            'col-sm-12'  => esc_html__( '1 Columns','newie'),
            'col-sm-6'  => esc_html__( 'Masonry 2 Columns','newie'),
            'col-sm-4'  => esc_html__( 'Masonry 3 Columns','newie'),
           
        );
        return apply_filters('newie_select_number_of_column', $newie_select_number_of_column);
    }
endif;


/**
 * newie select_number of columns option for realted post
 *
 * @since Newie 1.0.0
 *
 * @param null
 * @return array $newie_select_number_of_columns_reated_post_option
 *
 */
if (!function_exists('newie_select_number_of_columns_reated_post_option')) :
    function newie_select_number_of_columns_reated_post_option()
    {
        $newie_select_number_of_columns_reated_post_option = array(
            'col-sm-12'  => esc_html__( '1 Columns','newie'),
            'col-sm-6'  => esc_html__( '2 Columns','newie'),
            'col-sm-4'  => esc_html__( '3 Columns','newie'),
         
        );
        return apply_filters('newie_select_number_of_columns_reated_post_option', $newie_select_number_of_columns_reated_post_option);
    }
endif;


/**
 * Pagination option
 *
 * @since Newie 1.0.0
 *
 * @param null
 * @return array $newie_pagination_option
 *
 */
if (!function_exists('newie_pagination_option')) :
    function newie_pagination_option()
    {
        $newie_pagination_option = array(
            'default'   => esc_html__( 'Default','newie'),
            'numeric'   => esc_html__( 'Numeric','newie'),
        );
        return apply_filters('newie_pagination_option', $newie_pagination_option);
    }
endif;

/**
 * Reset Option
 *
 * @since Newie 1.0.0
 *
 * @param null
 * @return array $newie_reset_option
 *
 */
if (!function_exists('newie_reset_option')) :
    function newie_reset_option()
    {
        $newie_reset_option = array(
            'do-not-reset'  => esc_html__( 'Do Not Reset','newie'),
            'reset-all'     => esc_html__( 'Reset All','newie'),
        );
        return apply_filters('newie_reset_option', $newie_reset_option);
    }
endif;


/**
 * Font Weight Option
 *
 * @since newie 1.0.0
 *
 * @param null
 * @return array $newie_font_weight
 *
 */
if ( !function_exists('newie_font_weight') ) :
    function newie_font_weight() {
        $newie_font_weight =  array(
            'normal'             => esc_html__( 'Normal','newie'),
            'bold'               => esc_html__( 'Bold','newie'),
            'bolder'             => esc_html__( 'Bolder' ,'newie'),
            'lighter'            => esc_html__( 'Lighter','newie'),
            '100'                => esc_html__( '100','newie'),
            '600'                => esc_html__( '600','newie'),
            '700'                => esc_html__( '700','newie'),
            '800'                => esc_html__( '800','newie'),
            '900'                => esc_html__( '900','newie'),
           
        );
        return apply_filters( 'newie_font_weight', $newie_font_weight );
    }
endif;


/**
 * Font Style Option
 *
 * @since newie 1.0.0
 *
 * @param null
 * @return array $newie_font_style
 *
 */
if ( !function_exists('newie_font_style') ) :
    function newie_font_style() {
        $newie_font_style =  array(
            'normal'            => esc_html__( 'Normal','newie'),
            'italic'             => esc_html__( 'Italic','newie'),
            'oblique'           => esc_html__( 'Oblique' ,'newie'),
            
        );
        return apply_filters( 'newie_font_style', $newie_font_style );
    }
endif;


/**
 *  Default Theme options
 *
 * @since newie 1.0.0
 *
 * @param null
 * @return array $newie_theme_layout
 *
 */
if ( !function_exists('newie_default_theme_options') ) :
    function newie_default_theme_options() 
   {

        $default_theme_options = array(
            /*feature section options*/

            'site_identity'           => 'title-text',
            'site_logo_position'      => 'center-logo-image',
            'site_layout'             => 'full-width',
            'menu_postion'            => 'normal-menu',
            'show_sticky_menu'        => 1,
            'newie-feature-cat'       => 0,
            'newie-feature-tag'       => 0,
            'newie-promo-cat'         => 0,
            'newie-footer-copyright'  => esc_html__( 'Newie WordPress Theme, Copyright 2017', 'newie'),
            'newie-footer-powerby'  => wp_kses_post( '<a href="https://wordpress.org/">Proudly powered by WordPres</a> | Theme: Newie by <a href="http://paragonthemes.com" target="_blank">Paragon Themes</a>.', 'newie'),
            'newie-layout'            => 'right-sidebar',   
            'breadcrumb_option'       => 'simple',
            'newie-realted-post'      => 0,
            'newie-realted-post-title'=> esc_html__( 'Related Posts', 'newie' ),
            'hide-breadcrumb-at-home' => 1 ,
            'primary_color'           => '#222222',
            'slider-options'          => 'category',
            'newie-image-layout'      => 'large-image',
            'newie_columns_option'    => 'col-sm-12',
            'newie_blog_title_option' => 'Blog Title',
            'newie_description_length_option'=> 40,
            'newie_exclude_cat_blog_archive_option'    => '',
            'newie_read_more_text_blog_archive_option' => esc_html( 'Read More', 'newie' ),
            'newie_blog_show_date_option'              => 1,
            'newie_blog_show_author_option'            => 1,
            'newie_blog_show_cats_option'              => 1,
            'newie_blog_show_tags_option'              => 1,
            'newie_blog_show_comments_option'          => 1,
            'newie_hide_image_option'                  => 1,
            'newie_select_number_of_columns_reated_post_option' => 'col-sm-4',
            'newie_number_of_post_show_option'         => 3,
            'newie_show_image_option'                  => 1,
            'newie_show_categories_option'             => 1,
            'newie_show_tag_insingle_page'             => 1,
            'newie_show_date_insingle_page'            => 1,
            'newie_show_author_insingle_page'          => 1,
            'newie_show_comments_insingle_page'        => 1,
            'newie_post_pagination_option'             => 'default',
            'newie_number_of_word_realted'             => 15,
            'newie_loader_image'                       => '',
            'newie_loder_enable'                       => 1,
            'newie_loader_bg_color'                    => '#ffffff',
            'newie_top_footer_border_color'            => '#ccc',


             
             // Theme Color Options
            'newie_primary_color'                      => '#6e6e6e',
            'newie_top_header_background_color'        => '#ffffff',
            'newie_top_footer_background_color'        => '#f7f7f7',
            'newie_top_footer_title_color'             => '#333',
            'newie_top_footer_text_color'              => '#333',
            'newie_bottom_footer_background_color'     => '#e9e9e9',
            'newie_bottom_footer_text_color'           => '#333',
            'newie_site_title_color_option'            => '#333',
            'newie_site_title_hover_color_option'      => '#333',
            'newie_site_tagline_color_option'          => '#000',
            'newie_body_paragraph_color_option'        => '#000',
            'newie_heading_color_option'               => '#000',
            'newie_link_color_option'                  => '#151515',
            'newie_link_hover_color_option'            => '#5a8c59',
            'newie_menu_navbar_bg_color_option'        => '#ffffff',
            'newie_menu_active_color_option'           => '#5a8c59',
            'newie_menu_hover_color_option'            => '#5a8c59',
            'newie_menu_text_color_option'             => '#6e6e6e',
            'newie_slider_color_option'                => '#333',
            'newie_top_scroll_bg_color'                => '#FFF',
            'newie_top_scroll_icon_color'              => '#5a8c59',
            'newie_all_page'                           => 0,
            'newie_top_header_text_color'              => '#FFF',
            'newie_slider_bg_color_option'             => '#FFF',
            'newie_color_reset_option'                 => 'do-not-reset',
            
            // Site Title
            'newie_font_url'                           => wp_kses_post( 'https://fonts.googleapis.com/css?family=Hind:300,400,500|Libre+Franklin:400,500|Merriweather:400,700,700i,900','newie'),
            'newie_font_family'                        => "'Hind', sans-serif",
            'newie_font_size'                          => 50,
            'newie_font_weight'                        => 'normal',
            'newie_font_style'                         => 'normal',
            'newie_line_height'                        => 19,
            'newie_letter_space'                       => 0,

            // Site Description
            'newie_site_desc_font_url'                 => wp_kses_post( 'https://fonts.googleapis.com/css?family=Hind:300,400,500|Libre+Franklin:400,500|Merriweather:400,700,700i,900','newie'),
            'newie_site_desc_font_family'                        => "'Hind', sans-serif",
            'newie_site_desc_font_size'                          => 13,
            'newie_site_desc_font_weight'                        => 'normal',
            'newie_site_desc_font_style'                         => 'normal',
            'newie_site_desc_line_height'                        => 10,
            'newie_site_desc_letter_space'                       => 1,

             // Menu
             'newie_menu_font_url'                 => wp_kses_post( 'https://fonts.googleapis.com/css?family=Hind:300,400,500|Libre+Franklin:400,500|Merriweather:400,700,700i,900','newie'),
            'newie_menu_font_family'                        => "'Hind', sans-serif",
            'newie_menu_font_size'                          => 14,
            'newie_menu_font_weight'                        => 'normal',
            'newie_menu_font_style'                         => 'normal',
            'newie_menu_line_height'                        => 19,
            'newie_menu_letter_space'                       => 0,

             //Paragraph
            'newie_paragraph_font_url'                 => wp_kses_post( 'https://fonts.googleapis.com/css?family=Hind:300,400,500|Libre+Franklin:400,500|Merriweather:400,700,700i,900','newie'),
            'newie_paragraph_font_family'                        => "'Hind', sans-serif",
            'newie_paragraph_font_size'                          => 16,
            'newie_paragraph_font_weight'                        => 'normal',
            'newie_paragraph_font_style'                         => 'normal',
            'newie_paragraph_line_height'                        =>30,
            'newie_paragraph_letter_space'                       => 0,

           //Heading Options
            'newie_heading_font_url'                   => wp_kses_post( 'https://fonts.googleapis.com/css?family=Hind:300,400,500|Libre+Franklin:400,500|Merriweather:400,700,700i,900','newie'),
            'newie_heading_font_family'                      => "'Hind', sans-serif",
            'newie_h1_font_size'                             => 36,
            'newie_h2_font_size'                             => 32,
            'newie_h3_font_size'                             => 24,
            'newie_h4_font_size'                             => 20,
            'newie_h5_font_size'                             => 18,
            'newie_h6_font_size'                             => 16,
            'newie_no_of_slider'                             => 3,


        ); 

        return apply_filters( 'newie_default_theme_options', $default_theme_options );
    }
endif;

/**
 *  Get theme options
 *
 * @since newie 1.0.0
 *
 * @param null
 * @return array newie_theme_options
 *
 */
if ( !function_exists('newie_get_theme_options') ) :
    function newie_get_theme_options()
    {

        $newie_default_theme_options = newie_default_theme_options();
        

        $newie_get_theme_options = get_theme_mod( 'newie_theme_options');
        
        if( is_array( $newie_get_theme_options )){
          
            return array_merge( $newie_default_theme_options, $newie_get_theme_options );
        }

        else{

            return $newie_default_theme_options;
        }

    }
endif;

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function newie_customize_register( $wp_customize )
{
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	/*defaults options*/
    $defaults = newie_get_theme_options();
       
    /**
     * Load customizer custom-controls
     */
    require get_template_directory() . '/inc/customizer-inc/custom-controls.php';

    /**
     * Load customizer Theme Options
     */
    require get_template_directory() . '/inc/customizer-inc/newie-theme-options.php';

     /**
     * Load customizer Color section
     */
    require get_template_directory() . '/inc/customizer-inc/color-options.php';

      /**
     * Load customizer Typography section
     */
    require get_template_directory() . '/inc/customizer-inc/typography-options.php';


}
add_action( 'customize_register', 'newie_customize_register' );


/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function newie_customize_preview_js() 
{
	wp_enqueue_script( 'newie_customizer', get_template_directory_uri() . '/assets/js/customizer.js', array( 'jquery' ), '20151216', true );
}
add_action( 'customize_preview_init', 'newie_customize_preview_js' );


function newie_customizer_script() {
  
    wp_enqueue_style( 'newie-customizer-style', get_template_directory_uri() .'/inc/css/customizer-style.css'); 

    wp_enqueue_script( 'newie-alpha-color-picker', get_template_directory_uri() .'/inc/js/alpha-color-picker.js',array( 'jquery', 'wp-color-picker' ),
            time());   
}
add_action( 'customize_controls_enqueue_scripts', 'newie_customizer_script' );